@@ -6,14 +6,15 @@
 
 #include "grantleethememanager.h"
 
-#include <qtest.h>
-#include <QStandardPaths>
 #include <QMenu>
+#include <QStandardPaths>
+#include <qtest.h>
 
-#include <KConfigGroup>
-#include <KSharedConfig>
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KConfigGroup>
+#include <KSharedConfig>
+#include <QActionGroup>
 
 class GrantleeThemeManagerTest : public QObject
 {
@@ -35,7 +36,7 @@ void GrantleeThemeManagerTest::initTestCase()
     QStandardPaths::setTestModeEnabled(true);
 
     // Point the test to our dummy icon theme
-    KConfigGroup cg(KSharedConfig::openConfig(), "Icons");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Icons"));
     cg.writeEntry("Theme", "dummyTheme");
     qputenv("XDG_DATA_DIRS", GRANTLEETHEME_DATA_DIR);
 }
@@ -43,7 +44,7 @@ void GrantleeThemeManagerTest::initTestCase()
 void GrantleeThemeManagerTest::updateActionList()
 {
     KActionCollection coll(this);
-    GrantleeTheme::ThemeManager *manager(new GrantleeTheme::ThemeManager(QStringLiteral("Stuff"), QStringLiteral("filename.testdesktop"), &coll, QStringLiteral("themes")));
+    auto manager(new GrantleeTheme::ThemeManager(QStringLiteral("Stuff"), QStringLiteral("filename.testdesktop"), &coll, QStringLiteral("themes")));
     QCOMPARE(manager->themes().count(), 2);
     QVERIFY(!manager->actionForTheme()); // Bug? No "default" theme.
 
@@ -67,18 +68,18 @@ void GrantleeThemeManagerTest::updateActionList()
 void GrantleeThemeManagerTest::destructionOrderTest()
 {
     KActionCollection coll(this);
-    GrantleeTheme::ThemeManager *manager(new GrantleeTheme::ThemeManager(QStringLiteral("Stuff"), QStringLiteral("filename.testdesktop"), &coll, QStringLiteral("themes")));
+    auto manager(new GrantleeTheme::ThemeManager(QStringLiteral("Stuff"), QStringLiteral("filename.testdesktop"), &coll, QStringLiteral("themes")));
     QCOMPARE(manager->themes().count(), 2);
     QVERIFY(!manager->actionForTheme()); // Bug? No "default" theme.
 
-    auto *actionGroup = new QActionGroup(this);
+    auto actionGroup = new QActionGroup(this);
     manager->setActionGroup(actionGroup);
 
-    auto *menu = new KActionMenu(this);
+    auto menu = new KActionMenu(this);
     manager->setThemeMenu(menu);
     QCOMPARE(menu->menu()->actions().count(), 4); // 2 themes + separator + download
 
-    auto *menu2 = new KActionMenu(this);
+    auto menu2 = new KActionMenu(this);
     manager->setThemeMenu(menu2);
     QCOMPARE(menu2->menu()->actions().count(), 4);
 
